@@ -439,7 +439,7 @@ class IControlWidget(IWidget):
 
     @doc_inherit(IWidget.__init__, style='numpy_with_merge')
     def __init__(self, position, size,
-                 min_max=None,
+                 min_max,
                  start_value=None,
                  snap_value=None,
                  dynamic=None,
@@ -475,8 +475,13 @@ class IControlWidget(IWidget):
         self.min_val, self.max_val = (min_max)
         # Value is in 0..1, where adjusted_value is in min_val..max_val
         self.range = self.max_val - self.min_val
-        self.adjusted_value = self.min_val if start_value is None else start_value
-        self.value = (self.adjusted_value - self.min_val) / self.range
+
+        if start_value is not None:
+            self.adjusted_value = start_value
+            self.value = self.normalize_adjusted_value(start_value)
+        else:
+            self.adjusted_value = min_max[0]
+            self.value = self.normalize_adjusted_value(min_max[0])
 
         self.dynamic = False if dynamic is None else dynamic
 
@@ -548,6 +553,9 @@ class IControlWidget(IWidget):
         self.adjusted_value = value
         self.value = self.normalize_adjusted_value(value)
 
+        if self.function is not None:
+            return self.function(self, self.adjusted_value)
+
     def on_release(self, touch):
         """ Controls call their function on the release event.
 
