@@ -13,8 +13,7 @@ from typing import Tuple, Optional
 import pygame
 from custom_inherit import doc_inherit
 
-from pi_touch_gui._utilities import snapped_value_string
-from pi_touch_gui._widget_bases import (FONT_NAME, IButtonWidget,
+from pi_touch_gui._widget_bases import (IButtonWidget,
                                         IWidgetInterface)
 
 LOG = logging.getLogger(__name__)
@@ -127,8 +126,9 @@ class Button(IButtonWidget):
             self.active = not self.active
         else:
             self.active = False
-        return super(Button, self).release()
-
+        if self.function:
+            return self.function(self, False)
+        self._pressed = False
 
 
 class ButtonGroup(IWidgetInterface):
